@@ -81,8 +81,9 @@ class BaseParser:
 
                 # 将页面保存，等待进一步递归操作
                 # 保存子页面信息
-                common_op.debug_log("child_page_parser add page id = " + page_id + "_" + text_str)
-                text_str = content_format.get_page_format_md(page_id + "_" + text_str, text_str, export_child=self.export_child)
+                common_op.debug_log("child_page_parser add page id = " + page_id + "_" + text_str, level=NotionDump.DUMP_MODE_DEFAULT)
+                text_str = content_format.get_page_format_md(page_id + "_" + text_str, text_str,
+                                                             export_child=self.export_child)
 
         if parser_type == NotionDump.PARSER_TYPE_MD:
             # 解析annotations部分，为text_str添加格式
@@ -115,7 +116,7 @@ class BaseParser:
             common_op.debug_log("people type error! id=" + self.base_id, level=NotionDump.DUMP_MODE_DEFAULT)
             return ""
         # 优先获取名字
-        if block_handle["name"] is not None:
+        if "name" in block_handle.keys():
             return block_handle["name"]
         # 如果无法获取名字则返回id
         return block_handle["id"].replace('-', '')
@@ -127,16 +128,38 @@ class BaseParser:
         user_body = block_handle["user"]
         return self.__people_parser(user_body)
 
-    def __file_parser(self, block_handle, parser_type=NotionDump.PARSER_TYPE_PLAIN):
+    def __db_file_parser(self, block_handle, parser_type=NotionDump.PARSER_TYPE_PLAIN):
         if block_handle["type"] != "file":
             common_op.debug_log("file type error! id=" + self.base_id, level=NotionDump.DUMP_MODE_DEFAULT)
             return ""
         filename = block_handle["name"]
         file_url = block_handle["file"]["url"]
+
+        # 解析文件的ID
+        url_prefix = file_url[0:file_url.rfind("/")]
+        file_id = url_prefix[url_prefix.rfind("/") + 1:].replace('-', '')
+        common_op.debug_log("file id is : " + file_id)
+
+        if filename == "":
+            # 如果文件没有名字使用id作为默认名字
+            filename = file_id
+        common_op.add_new_child_page(
+            self.child_pages,
+            key_id=file_id,
+            link_id=file_url,
+            page_type="file",
+            page_name=filename
+        )
+        common_op.debug_log(
+            "file_parser add page id = " + file_id + "name : " + filename, level=NotionDump.DUMP_MODE_DEFAULT)
+        common_op.debug_log(internal_var.PAGE_DIC)
+        common_op.debug_log("#############")
+        common_op.debug_log(self.child_pages)
+
         # 格式处理简单格式（也可以转换成markdown格式[]()）
         if parser_type == NotionDump.PARSER_TYPE_MD:
             # file转换成文件链接的形式
-            return content_format.get_file_format_md(filename, file_url)
+            return content_format.get_file_format_md(filename, file_url, file_id, self.export_child)
         else:
             return content_format.get_file_format_plain(filename, file_url)
 
@@ -145,9 +168,11 @@ class BaseParser:
         if block_handle["type"] != "equation":
             common_op.debug_log("equation inline type error! id=" + self.base_id, level=NotionDump.DUMP_MODE_DEFAULT)
             return ""
-        return content_format.get_equation_inline(
-            self.__annotations_parser(block_handle["annotations"], block_handle["plain_text"])
-        )
+        # 公式删除富文本格式
+        # return content_format.get_equation_inline(
+        #     self.__annotations_parser(block_handle["annotations"], block_handle["plain_text"])
+        # )
+        return content_format.get_equation_inline(block_handle["plain_text"])
 
     # "$$ equation_block $$"
     def __equation_block_parser(self, block_handle):
@@ -177,24 +202,57 @@ class BaseParser:
             mention_plain = self.date_parser(mention_body)
         elif mention_body["type"] == "user":
             mention_plain = self.__user_parser(mention_body)
+        elif mention_body["type"] == "database":
+            database_id = mention_body["database"]["id"].replace('-', '')
+            key_id = database_id + "_mention"
+            common_op.debug_log("__mention_parser add database id = " + database_id)
+            # 获取页面的名字
+            database_name = block_handle["plain_text"]
+            common_op.add_new_child_page(
+                self.child_pages,
+                key_id=key_id,
+                link_id=database_id,
+                page_type="database",
+                page_name=database_name
+            )
+            common_op.debug_log(
+                "file_parser add page id = " + key_id + "name : " + database_name, level=NotionDump.DUMP_MODE_DEFAULT)
+            common_op.debug_log(internal_var.PAGE_DIC)
+            common_op.debug_log("#############")
+            common_op.debug_log(self.child_pages)
+
+            if parser_type == NotionDump.PARSER_TYPE_MD:
+                mention_plain = content_format.get_page_format_md(key_id, database_name, export_child=self.export_child)
+            else:
+                mention_plain = database_name
         elif mention_body["type"] == "page":
             page_id = self.__page_parser(mention_body)
+            key_id = page_id + "_mention"
             common_op.debug_log("__mention_parser add page id = " + page_id)
             # 获取页面的名字
             page_name = block_handle["plain_text"]
-            if page_name is None:
-                # 提及到的其它页面因为没有别名，按照一个页面处理
-                common_op.add_new_child_page(self.child_pages, key_id=page_id)
-                page_name = page_id
-            else:
-                common_op.add_new_child_page(self.child_pages, key_id=page_id, page_name=page_name)
+
+            # 提及页面按照链接页面处理
+            common_op.add_new_child_page(
+                self.child_pages,
+                key_id=key_id,
+                link_id=page_id,
+                page_type="page",
+                page_name=page_name
+            )
+            common_op.debug_log(
+                "file_parser add page id = " + key_id + "name : " + page_name, level=NotionDump.DUMP_MODE_DEFAULT)
+            common_op.debug_log(internal_var.PAGE_DIC)
+            common_op.debug_log("#############")
+            common_op.debug_log(self.child_pages)
 
             if parser_type == NotionDump.PARSER_TYPE_MD:
-                mention_plain = content_format.get_page_format_md(page_id, page_name, export_child=self.export_child)
+                mention_plain = content_format.get_page_format_md(key_id, page_name, export_child=self.export_child)
             else:
                 mention_plain = page_name
         else:
             common_op.debug_log("unknown mention type " + mention_body["type"], level=NotionDump.DUMP_MODE_DEFAULT)
+
         if parser_type == NotionDump.PARSER_TYPE_MD:
             # 解析annotations部分，为mention_plain添加格式
             return self.__annotations_parser(block_handle["annotations"],
@@ -209,7 +267,7 @@ class BaseParser:
         table_col_cells = block_handle["table_row"]["cells"]
         table_row = []
         for cell in table_col_cells:
-            table_row.append(self.__text_parser(cell[0], parser_type))
+            table_row.append(self.__text_list_parser(cell, parser_type))
         return table_row
 
     # 数据库 title
@@ -222,7 +280,7 @@ class BaseParser:
         if title_ret != "":
             # 如果存在子Page就加入到待解析队列
             common_op.debug_log("title ret = " + title_ret)
-            common_op.debug_log("title_parser add page id = " + page_id)
+            common_op.debug_log("title_parser add page id = " + page_id, level=NotionDump.DUMP_MODE_DEFAULT)
             # 数据库里的都是子页面
             common_op.add_new_child_page(self.child_pages, key_id=page_id, page_name=title_ret)
 
@@ -367,8 +425,11 @@ class BaseParser:
             return ret_str
         for file in files_list:
             if ret_str != "":
-                ret_str += ","  # 多个文件之间用“,”分割
-            ret_str += self.__file_parser(file, parser_type)
+                if parser_type == NotionDump.PARSER_TYPE_MD:
+                    ret_str += "<br>"  # 多个文件之间用“<br>”分割
+                else:
+                    ret_str += ","  # 多个文件之间用“,”分割
+            ret_str += self.__db_file_parser(file, parser_type)
         return ret_str
 
     # 数据库 rollup 数据
@@ -605,7 +666,7 @@ class BaseParser:
             page_id = (block_handle["id"]).replace('-', '')
 
             # 保存子页面信息
-            common_op.debug_log("child_page_parser add page id = " + page_id)
+            common_op.debug_log("child_page_parser add page id = " + page_id, level=NotionDump.DUMP_MODE_DEFAULT)
             common_op.add_new_child_page(self.child_pages, key_id=page_id, page_name=page_body["title"])
 
             if parser_type == NotionDump.PARSER_TYPE_MD:
@@ -629,7 +690,7 @@ class BaseParser:
             page_name=block_handle["child_database"]["title"]
         )
         common_op.debug_log(
-            "child_database_parser add page id = " + child_db_id + "name : " + block_handle["child_database"]["title"])
+            "child_database_parser add page id = " + child_db_id + "name : " + block_handle["child_database"]["title"], level=NotionDump.DUMP_MODE_DEFAULT)
         common_op.debug_log(internal_var.PAGE_DIC)
         common_op.debug_log("#############")
         common_op.debug_log(self.child_pages)
@@ -654,7 +715,14 @@ class BaseParser:
         # 子数据库保存在页面表中，不解析
         image_id = block_handle["id"].replace('-', '')
         image_name = self.__text_list_parser(block_handle["image"]["caption"], parser_type)
-        image_url = block_handle["image"]["file"]["url"]
+        image_url = ""
+        image_type = block_handle["image"]["type"]
+        if image_type in block_handle["image"].keys():
+            if "url" in block_handle["image"][image_type].keys():
+                image_url = block_handle["image"][image_type]["url"]
+        if image_url == "":
+            common_op.debug_log("unknown image type" + block_handle["image"]["type"],
+                                level=NotionDump.DUMP_MODE_DEFAULT)
         if image_name == "":
             # 如果文件没有名字使用id作为默认名字
             image_name = image_id
@@ -667,7 +735,7 @@ class BaseParser:
         )
 
         common_op.debug_log(
-            "image_parser add page id = " + image_id + "name : " + image_name)
+            "image_parser add page id = " + image_id + "name : " + image_name, level=NotionDump.DUMP_MODE_DEFAULT)
         common_op.debug_log(internal_var.PAGE_DIC)
         common_op.debug_log("#############")
         common_op.debug_log(self.child_pages)
@@ -682,16 +750,24 @@ class BaseParser:
         else:
             return content_format.get_page_format_plain(image_name)
 
-    # Page file
+    # Page file(file,pdf)
     def file_parser(self, block_handle, parser_type=NotionDump.PARSER_TYPE_PLAIN):
-        if block_handle["type"] != "file":
+        if block_handle["type"] != "file" and block_handle["type"] != "pdf":
             common_op.debug_log("file type error! parent_id= " + self.base_id + " id= " + block_handle["id"],
                                 level=NotionDump.DUMP_MODE_DEFAULT)
             return ""
 
+        block_type = block_handle["type"]
         file_id = block_handle["id"].replace('-', '')
-        file_name = self.__text_list_parser(block_handle["file"]["caption"], parser_type)
-        file_url = block_handle["file"]["file"]["url"]
+        file_name = self.__text_list_parser(block_handle[block_type]["caption"], parser_type)
+        file_url = ""
+        file_type = block_handle[block_type]["type"]
+        if file_type in block_handle[block_type].keys():
+            if "url" in block_handle[block_type][file_type].keys():
+                file_url = block_handle[block_type][file_type]["url"]
+        if file_url == "":
+            common_op.debug_log("unknown block type" + block_handle[block_type]["type"],
+                                level=NotionDump.DUMP_MODE_DEFAULT)
         if file_name == "":
             # 如果文件没有名字使用id作为默认名字
             file_name = file_id
@@ -704,7 +780,7 @@ class BaseParser:
         )
 
         common_op.debug_log(
-            "file_parser add page id = " + file_id + "name : " + file_name)
+            "file_parser add page id = " + file_id + "name : " + file_name, level=NotionDump.DUMP_MODE_DEFAULT)
         common_op.debug_log(internal_var.PAGE_DIC)
         common_op.debug_log("#############")
         common_op.debug_log(self.child_pages)
@@ -718,3 +794,56 @@ class BaseParser:
             )
         else:
             return content_format.get_page_format_plain(file_name)
+
+    # Page bookmark
+    def bookmark_parser(self, block_handle, parser_type=NotionDump.PARSER_TYPE_PLAIN):
+        bookmark_ret = ""
+        if block_handle["type"] != "bookmark":
+            common_op.debug_log("bookmark type error! parent_id= " + self.base_id + " id= " + block_handle["id"],
+                                level=NotionDump.DUMP_MODE_DEFAULT)
+            return bookmark_ret
+        bookmark_name = self.__text_list_parser(block_handle["bookmark"]["caption"], parser_type)
+        if bookmark_name == "":
+            bookmark_name = block_handle["id"]
+        bookmark_url = block_handle["bookmark"]["url"]
+
+        # bookmark 类型要返回一个链接占位符，供后续解析使用
+        if parser_type == NotionDump.PARSER_TYPE_MD:
+            # file转换成文件链接的形式
+            return content_format.get_file_format_md(bookmark_name, bookmark_url)
+        else:
+            return content_format.get_file_format_plain(bookmark_name, bookmark_url)
+
+    # Page link_to_page
+    def link_to_page_parser(self, block_handle, parser_type=NotionDump.PARSER_TYPE_PLAIN):
+        link_to_page_ret = ""
+        if block_handle["type"] != "link_to_page":
+            common_op.debug_log("link_to_page type error! parent_id= " + self.base_id + " id= " + block_handle["id"],
+                                level=NotionDump.DUMP_MODE_DEFAULT)
+            return link_to_page_ret
+
+        link_page = block_handle["link_to_page"]
+        if link_page["type"] == "page_id":
+            page_id = link_page["page_id"].replace('-', '')
+            page_name = ""
+            key_id = page_id + "_link_page"
+            common_op.add_new_child_page(
+                self.child_pages,
+                key_id=key_id,
+                link_id=page_id,
+                page_type="page",
+                page_name=page_name
+            )
+            common_op.debug_log(
+                "link_to_page_parser add link_page key_id = " + key_id, level=NotionDump.DUMP_MODE_DEFAULT)
+            common_op.debug_log(internal_var.PAGE_DIC)
+            common_op.debug_log("#############")
+            common_op.debug_log(self.child_pages)
+            return content_format.get_page_format_md(
+                key_id,
+                page_name,
+                export_child=self.export_child
+            )
+        else:
+            common_op.debug_log("unknown type " + link_page["type"], level=NotionDump.DUMP_MODE_DEFAULT)
+        return link_to_page_ret
