@@ -125,9 +125,15 @@ class BlockParser:
         elif block_type == "image":
             # Page image
             block_text = self.base_parser.image_parser(block, self.parser_type)
-        elif block_type == "file":
+        elif block_type == "file" or block_type == "pdf":
             # Page file
             block_text = self.base_parser.file_parser(block, self.parser_type)
+        elif block_type == "bookmark":
+            # Page bookmark
+            block_text = self.base_parser.bookmark_parser(block, self.parser_type)
+        elif block_type == "link_to_page":
+            # Page link_to_page
+            block_text = self.base_parser.link_to_page_parser(block, self.parser_type)
         else:
             common_op.debug_log("unknown page block properties type:" + block_type, level=NotionDump.DUMP_MODE_DEFAULT)
         return block_text
@@ -183,6 +189,10 @@ class BlockParser:
 
     def block_to_md(self, block_handle, new_id=None):
         block_list = block_handle["results"]
+        # 空内容不生成文件
+        if len(block_list) == 0:
+            return ""
+
         # 创建Markdown文件
         if new_id is not None:
             tmp_md_filename = self.tmp_dir + new_id.replace('-', '') + ".md"
