@@ -9,17 +9,19 @@ from NotionDump.Dump.dump import Dump
 from NotionDump.Notion.Notion import NotionQuery
 from NotionDump.utils import common_op
 
-TOKEN_TEST = "secret_WRLJ9xyEawNxzRhVHVWfciTl9FAyNCd29GMUvr2hQD4"
-PAGE_MIX_ID = "6138380c8d3d4c31884f4f90da60a4f1"
+TOKEN_TEST = "secret_g6easunNXs3S5OdTS4qBhlPZN9fjxTkdJ80wOImK5cZ"
+PAGE_MIX_ID = "950e57e0507b4448a55a13b2f47f031f"
+NotionDump.DUMP_MODE = NotionDump.DUMP_MODE_DEBUG
 
 
 # 解析数据库内容测试：根据token和id解析数据库内容，得到临时CSV文件
-def test_page_parser(query, export_child=False):
+def test_page_parser(query, export_child=False, db_parser_type=NotionDump.PARSER_TYPE_MD):
     page_handle = Dump(
         dump_id=PAGE_MIX_ID,
         query_handle=query,
         export_child_pages=export_child,
-        dump_type=NotionDump.DUMP_TYPE_PAGE
+        dump_type=NotionDump.DUMP_TYPE_PAGE,
+        db_parser_type=db_parser_type
     )
     # 将解析内容存储到文件中；返回内容存储为json文件
     page_detail_json = page_handle.dump_to_file()
